@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.19.0";
+our $VERSION = "v6.20.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 81 of the 100+ operators in rxjs are implemented in this module.
+Currently 86 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -281,6 +281,8 @@ L<https://rxjs.dev/api/index/class/Observable>
         Mojo::IOLoop->recurring(1, sub {$subscriber->next(rand())});
     });
 
+Check the L<guide to creating your own observables|RxPerl::Guides::CreatingObservables>.
+
 =item rx_of
 
 L<https://rxjs.dev/api/index/function/of>
@@ -780,6 +782,23 @@ Same as rxjs's I<isEmpty>, but emits 1 or 0 instead of true or false.
         op_is_empty(),
     )->subscribe($observer);
 
+=item op_last
+
+L<https://rxjs.dev/api/operators/last>
+
+    # 6, complete
+    rx_of(5, 6, 7)->pipe(
+        op_last(sub ($val, $idx) { $val % 2 == 0 }), # could also use $_ here
+    )->subscribe($observer);
+
+    # 9, complete
+    rx_EMPTY->pipe(
+        op_last(undef, 9), # predicate, default
+    )->subscribe($observer);
+
+    # error: no last value found
+    rx_EMPTY->pipe( op_last )->subscribe($observer);
+
 =item op_map
 
 L<https://rxjs.dev/api/operators/map>
@@ -810,6 +829,24 @@ L<https://rxjs.dev/api/operators/mapTo>
         op_map_to(123),
     )->subscribe($observer);
 
+=item op_max
+
+L<https://rxjs.dev/api/operators/max>
+
+    # 20, complete
+    rx_of(10, 20, 15)->pipe(
+        op_max(),
+    )->subscribe($observer);
+
+    # { a => 20 }, complete
+    rx_of(
+        { a => 10 },
+        { a => 20 },
+        { a => 15 },
+    )->pipe(
+        op_max(sub ($x, $y) { $x->{a} <=> $y->{a} }),
+    )->subscribe($observer);
+
 =item op_merge_all
 
 L<https://rxjs.dev/api/operators/mergeAll>
@@ -845,6 +882,24 @@ L<https://rxjs.dev/api/operators/mergeWith>
         rx_merge_with( rx_interval(1) ),
     )->subscribe($observer);
 
+=item op_min
+
+L<https://rxjs.dev/api/operators/min>
+
+    # 10, complete
+    rx_of(20, 10, 15)->pipe(
+        op_min(),
+    )->subscribe($observer);
+
+    # { a => 10 }, complete
+    rx_of(
+        { a => 20 },
+        { a => 10 },
+        { a => 15 },
+    )->pipe(
+        op_min(sub ($x, $y) { $x->{a} <=> $y->{a} }),
+    )->subscribe($observer);
+
 =item op_multicast
 
 L<https://rxjs.dev/api/operators/multicast>
@@ -887,6 +942,18 @@ L<https://rxjs.dev/api/operators/pluck>
         op_pluck('name', 'first'),
     )->subscribe($observer);
 
+=item op_race_with
+
+L<https://rxjs.dev/api/operators/raceWith>
+
+    # 0, 1, 2, 3, 4, ... (every second)
+    rx_interval(3)->pipe(
+        op_race_with(
+            rx_interval(2),
+            rx_interval(1),
+        ),
+    )->subscribe($observer);
+
 =item op_reduce
 
 L<https://rxjs.dev/api/operators/reduce>
@@ -1029,6 +1096,15 @@ L<https://rxjs.dev/api/operators/take>
         op_take(5),
     )->subscribe($observer);
 
+=item op_take_last
+
+L<https://rxjs.dev/api/operators/takeLast>
+
+    # 3, 5, 6, complete
+    rx_of(1, 2, 3, 5, 6)->pipe(
+        op_take_last(3),
+    )->subscribe($observer);
+
 =item op_take_until
 
 L<https://rxjs.dev/api/operators/takeUntil>
